| Title: | Extract Drugs from Differential Expression Data |
|---|---|
| Description: | Extract Drugs from Differential Expression Data using the Connectivity Map (CMAP) Approach and Library of Integrated Network-Based Cellular Signatures (LINCS) Database. |
| Authors: | Mohamed Soudy [aut, cre] |
| Maintainer: | Mohamed Soudy <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.0 |
| Built: | 2026-05-13 09:26:25 UTC |
| Source: | https://github.com/mohmedsoudy/dfd |
The function is used to convert gene symbols to entrez ids and map the genes to human orthologs
convert_id(gene_symbols)convert_id(gene_symbols)
gene_symbols |
gene symbols |
ENTREZ gene ids
Mohamed Soudy [email protected]
convert_id(c("TP53", "A2M"))convert_id(c("TP53", "A2M"))
The function is used to re-rank drugs based on their targets
filter_drugs(drug_frame)filter_drugs(drug_frame)
drug_frame |
drugs data frame returned by 'get_drugs' function |
Mohamed Soudy [email protected]
The function is used to get list of drugs that are associated with differential expression profile
get_drugs(up_regulated, down_regulated)get_drugs(up_regulated, down_regulated)
up_regulated |
up-regulated genes returned by 'prepare_ids' function |
down_regulated |
down-regulated genes returned by 'prepare_ids' function |
Mohamed Soudy [email protected]
The function is used to prepare the ids for the CMAP search
prepare_ids(up_regulated, down_regulated)prepare_ids(up_regulated, down_regulated)
up_regulated |
up regulated gene symbols |
down_regulated |
down regulated gene symbols |
ENTREZ gene ids
Mohamed Soudy [email protected]
The function is used to read IDs from a CSV file
read_id(csv_path)read_id(csv_path)
csv_path |
absolute path of CSV file containing gene symbols and sign |
up_regulated and down_regulated genes
Mohamed Soudy [email protected]
The function is used to run the main pipeline by extracting the drug list given differential expressed genes
run_pipeline(degs_path, output_path = NULL)run_pipeline(degs_path, output_path = NULL)
degs_path |
path to csv file containing degs see example file at https://raw.githubusercontent.com/MohmedSoudy/datasharing/master/differential-expression.csv |
output_path |
absolute path to output directory |
Mohamed Soudy [email protected]